@@ -257,7 +257,7 @@ class TemplateParser(object):
     def __init__(self, text,
                  name    = "ParserContainer",
                  context = dict(),
-                 path    = 'views/',
+                 path    = os.getcwd(),
                  writer  = 'sys.stdout.write',
                  #writer  = 'print',
                  lexers  = {},
